@@ -26,7 +26,7 @@ FullLetterWidget::FullLetterWidget(QWidget *parent) :
 {
     ui->setupUi(this);
 
-    init_widget();
+    initWidget();
 }
 
 FullLetterWidget::~FullLetterWidget()
@@ -38,7 +38,7 @@ FullLetterWidget::~FullLetterWidget()
 /**
  * 主界面初始化
  */
-void FullLetterWidget::init_widget()
+void FullLetterWidget::initWidget()
 {
     this->setWindowFlags(Qt::CustomizeWindowHint | Qt::FramelessWindowHint);
     this->setAttribute(Qt::WA_StyledBackground,true);
@@ -62,14 +62,17 @@ void FullLetterWidget::init_widget()
     this->setLayout(mainLayout);
     pUkuiMenuInterface=new UkuiMenuInterface;
 
-    init_applist_widget();
-    init_letterlist_widget();
+    timer=new QTimer(this);
+    connect(timer,SIGNAL(timeout()),this,SLOT(timeOutSlot()));
+
+    initAppListWidget();
+    initLetterListWidget();
 }
 
 /**
  * 初始化应用列表界面
  */
-void FullLetterWidget::init_applist_widget()
+void FullLetterWidget::initAppListWidget()
 {
     QHBoxLayout* layout=new QHBoxLayout(applistWid);
     layout->setContentsMargins(0,0,0,0);
@@ -85,20 +88,22 @@ void FullLetterWidget::init_applist_widget()
     scrollareawidLayout->setSpacing(0);
     scrollareawid->setLayout(scrollareawidLayout);
     layout->addWidget(scrollarea);
+    connect(scrollarea->verticalScrollBar(),SIGNAL(valueChanged(int)),
+            this,SLOT(valueChangedSlot(int)));
 
-    fill_app_list();
+    fillAppList();
 
 }
 
 /**
  * 填充应用列表
  */
-void FullLetterWidget::fill_app_list()
+void FullLetterWidget::fillAppList()
 {
     letterbtnlist.clear();
     letterbtnrowlist.clear();
 
-    QVector<QStringList> vector=pUkuiMenuInterface->get_alphabetic_classification();
+    QVector<QStringList> vector=pUkuiMenuInterface->getAlphabeticClassification();
     for(int i=0;i<vector.size();i++)
     {
         QStringList appList=vector.at(i);
@@ -123,28 +128,29 @@ void FullLetterWidget::fill_app_list()
             data.clear();
             for(int i=0;i<appList.count();i++)
             {
-                QString desktopfp=pUkuiMenuInterface->get_desktop_path_by_app_name(appList.at(i));
+                QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(appList.at(i));
                 data.append(desktopfp);
 
             }
             listview->addData(data);
 
-            connect(listview,SIGNAL(sendItemClickedSignal(QString)),this,SLOT(exec_app_name(QString)));
-            connect(listview,SIGNAL(sendFixedOrUnfixedSignal()),this,SIGNAL(send_update_applist_signal()));
-            connect(listview,SIGNAL(send_hide_mainwindow_signal()),this,SIGNAL(send_hide_mainwindow_signal()));
+            connect(listview,SIGNAL(sendItemClickedSignal(QString)),this,SLOT(execApplication(QString)));
+            connect(listview,SIGNAL(sendFixedOrUnfixedSignal()),this,SIGNAL(sendUpdateAppListSignal()));
+            connect(listview,SIGNAL(sendHideMainWindowSignal()),this,SIGNAL(sendHideMainWindowSignal()));
         }
     }
 
-        resize_scrollarea_controls();
+        resizeScrollAreaControls();
 }
 
 /**
  * 执行应用程序
  */
-void FullLetterWidget::exec_app_name(QString appname)
+void FullLetterWidget::execApplication(QString appname)
 {
-    Q_EMIT send_hide_mainwindow_signal();
-    QString execpath=pUkuiMenuInterface->get_app_exec(pUkuiMenuInterface->get_desktop_path_by_app_name(appname));
+    qDebug()<<appname;
+    Q_EMIT sendHideMainWindowSignal();
+    QString execpath=pUkuiMenuInterface->getAppExec(pUkuiMenuInterface->getDesktopPathByAppName(appname));
     //移除启动参数%u或者%U
     if(execpath.contains("%"))
     {
@@ -158,7 +164,7 @@ void FullLetterWidget::exec_app_name(QString appname)
 /**
  * 更新应用列表
  */
-void FullLetterWidget::update_app_listview()
+void FullLetterWidget::updateAppListView()
 {
     //刷新应用列表界面
     for(int index=scrollareawidLayout->count()-1;index>=0;index--)
@@ -170,7 +176,7 @@ void FullLetterWidget::update_app_listview()
             delete wid;
     }
 
-    fill_app_list();
+    fillAppList();
 
     //刷新字母列表界面
     Q_FOREACH (QAbstractButton* button, buttonList) {
@@ -218,7 +224,7 @@ void FullLetterWidget::update_app_listview()
 /**
  * 设置scrollarea所填充控件大小
  */
-void FullLetterWidget::resize_scrollarea_controls()
+void FullLetterWidget::resizeScrollAreaControls()
 {
     int pos=0;
     letterbtnrowlist.append(QString::number(pos));
@@ -263,7 +269,7 @@ void FullLetterWidget::resize_scrollarea_controls()
 /**
  * 初始化字母列表界面
  */
-void FullLetterWidget::init_letterlist_widget()
+void FullLetterWidget::initLetterListWidget()
 {
     letterlistleftSpacer=new QSpacerItem(40,20,QSizePolicy::Expanding,QSizePolicy::Fixed);
     letterlistrightSpacer=new QSpacerItem(40,20,QSizePolicy::Expanding,QSizePolicy::Fixed);
@@ -274,7 +280,6 @@ void FullLetterWidget::init_letterlist_widget()
     letterlistWid->setLayout(letterlistLayout);
 
     letterlistscrollarea=new ClassifyScrollArea();
-//    letterlistscrollarea->setFixedSize(25,28*30+27*10);
     letterlistscrollarea->setFixedSize(Style::LeftBtnHeight,letterlistWid->height());
     letterlistscrollareaWid=new QWidget;
     letterlistscrollareawidLayout=new QVBoxLayout;
@@ -286,13 +291,14 @@ void FullLetterWidget::init_letterlist_widget()
 
     letterlistLayout->addWidget(letterlistscrollarea);
     pBtnGroup=new QButtonGroup(letterlistscrollareaWid);
-    init_letterlist_scrollarea();
+
+    initLetterListScrollArea();
 }
 
 /**
  * 初始化字母列表
  */
-void FullLetterWidget::init_letterlist_scrollarea()
+void FullLetterWidget::initLetterListScrollArea()
 {
     char btnstyle[500];
     sprintf(btnstyle,"QToolButton{background:transparent;color:#8b8b8b;padding-left:0px;border-radius:2px;}\
@@ -317,20 +323,22 @@ void FullLetterWidget::init_letterlist_scrollarea()
         letterbtn->setFont(font);
         buttonList.append(letterbtn);
         letterlistscrollareawidLayout->addWidget(letterbtn);
-//        connect(letterbtn,SIGNAL(clicked()),this,SLOT(letterbtn_clicked_slot()));
+//        connect(letterbtn,SIGNAL(clicked()),this,SLOT(letterBtnClickedSlot()));
     }
     int id=0;
     Q_FOREACH (QAbstractButton* btn, buttonList) {
         pBtnGroup->addButton(btn,id++);
     }
 
-    connect(pBtnGroup,SIGNAL(buttonClicked(QAbstractButton*)),this,SLOT(btngroup_clicked_slot(QAbstractButton*)));
+    connect(pBtnGroup,SIGNAL(buttonClicked(QAbstractButton*)),this,SLOT(btnGroupClickedSlot(QAbstractButton*)));
     letterlistscrollarea->widget()->adjustSize();
     pBtnGroup->button(0)->click();
 }
 
-void FullLetterWidget::btngroup_clicked_slot(QAbstractButton *btn)
+void FullLetterWidget::btnGroupClickedSlot(QAbstractButton *btn)
 {
+    disconnect(scrollarea->verticalScrollBar(),SIGNAL(valueChanged(int)),
+            this,SLOT(valueChangedSlot(int)));
     Q_FOREACH (QAbstractButton* button, buttonList) {
         if(pBtnGroup->id(btn)==buttonList.indexOf(button))
         {
@@ -340,8 +348,10 @@ void FullLetterWidget::btngroup_clicked_slot(QAbstractButton *btn)
             int num=letterbtnlist.indexOf(letterstr);
             if(num!=-1)
             {
-                int pos=letterbtnrowlist.at(num).toInt();
-                scrollarea->verticalScrollBar()->setSliderPosition(pos);
+                beginPos=scrollarea->verticalScrollBar()->sliderPosition();
+                endPos=letterbtnrowlist.at(num).toInt();
+                timer->start(1);
+//                scrollarea->verticalScrollBar()->setSliderPosition(pos);
             }
         }
         else{
@@ -350,7 +360,72 @@ void FullLetterWidget::btngroup_clicked_slot(QAbstractButton *btn)
     }
 }
 
-void FullLetterWidget::widget_make_zero()
+void FullLetterWidget::timeOutSlot()
+{
+
+    if(beginPos<endPos)
+    {
+        if(endPos-scrollarea->verticalScrollBar()->sliderPosition()<50)
+            scrollarea->verticalScrollBar()->setSliderPosition(endPos);
+        else
+            scrollarea->verticalScrollBar()->setSliderPosition(scrollarea->verticalScrollBar()->sliderPosition()+50);
+    }
+    else
+    {
+        if(scrollarea->verticalScrollBar()->sliderPosition()-endPos<50)
+            scrollarea->verticalScrollBar()->setSliderPosition(endPos);
+        else
+            scrollarea->verticalScrollBar()->setSliderPosition(scrollarea->verticalScrollBar()->sliderPosition()-50);
+    }
+    if(scrollarea->verticalScrollBar()->sliderPosition()==endPos ||
+            scrollarea->verticalScrollBar()->sliderPosition()>=scrollarea->verticalScrollBar()->maximum())
+    {
+        timer->stop();
+        connect(scrollarea->verticalScrollBar(),SIGNAL(valueChanged(int)),
+                this,SLOT(valueChangedSlot(int)));
+    }
+}
+
+void FullLetterWidget::valueChangedSlot(int value)
+{
+    int count=0;
+    while(count<letterbtnrowlist.count()-1)
+    {
+        if(value>=letterbtnrowlist.at(count).toInt() &&
+                value <letterbtnrowlist.at(count+1).toInt())
+        {
+            buttonList.at(count)->setChecked(true);
+            break;
+        }
+        else
+            count++;
+    }
+    if(count==letterbtnrowlist.count()-1 ||
+            scrollarea->verticalScrollBar()->sliderPosition()==scrollarea->verticalScrollBar()->maximum())
+    {
+        buttonList.at(letterbtnrowlist.count()-1)->setChecked(true);
+        letterlistscrollarea->verticalScrollBar()->setSliderPosition(letterlistscrollarea->verticalScrollBar()->maximum());
+
+    }
+
+    //向下滚动
+    if((buttonList.at(count)->pos().y()+buttonList.at(count)->height()+letterlistscrollarea->widget()->pos().y()) >= letterlistscrollarea->height())
+    {
+        int val=letterlistscrollarea->verticalScrollBar()->sliderPosition()+buttonList.at(count)->height();
+        letterlistscrollarea->verticalScrollBar()->setSliderPosition(val);
+    }
+
+    //向上滚动
+    if((buttonList.at(count)->pos().y()+letterlistscrollarea->widget()->pos().y()) <= 0)
+    {
+
+        int val=letterlistscrollarea->verticalScrollBar()->value()-buttonList.at(count)->height();
+        letterlistscrollarea->verticalScrollBar()->setSliderPosition(val);
+    }
+
+}
+
+void FullLetterWidget::widgetMakeZero()
 {
     Q_FOREACH (QAbstractButton* button, buttonList) {
         QString letterstr=button->text().at(0);
@@ -358,100 +433,8 @@ void FullLetterWidget::widget_make_zero()
         if(num!=-1)
         {
             pBtnGroup->button(num)->click();
+            letterlistscrollarea->verticalScrollBar()->setSliderPosition(0);
             break;
         }
     }
 }
-
-///**
-// * 向左按钮槽函数
-// */
-//void FullLetterWidget::leftbtn_clicked_slot()
-//{
-//    if(btnPos>0)
-//    {
-//        QLayoutItem* afteritem=letterlistscrollarea->widget()->layout()->itemAt(btnPos--);
-//        QWidget* afterwid=afteritem->widget();
-//        QToolButton* afterbtn=qobject_cast<QToolButton*>(afterwid);
-//        afterbtn->setChecked(false);
-//        QLayoutItem* item=letterlistscrollarea->widget()->layout()->itemAt(btnPos);
-//        QWidget* wid=item->widget();
-//        QToolButton* btn=qobject_cast<QToolButton*>(wid);
-//        btn->click();
-////        btn->checkStateSet();
-////        int pos=btnPosList.at(btnPos).toInt();
-//        if((btn->pos().x()+letterlistscrollarea->widget()->pos().x()) <= 0)
-//        {   if(btnPos>0)
-//            {
-//                int val=letterlistscrollarea->horizontalScrollBar()->value();
-//                letterlistscrollarea->horizontalScrollBar()->setValue(val-40);
-//            }
-//            else{
-////                qDebug()<<letterlistscrollarea->horizontalScrollBar()->minimum();
-//                letterlistscrollarea->horizontalScrollBar()->setValue(letterlistscrollarea->horizontalScrollBar()->minimum());
-//            }
-
-//        }
-
-//    }
-//}
-
-///**
-// * 向右按钮槽函数
-// */
-//void FullLetterWidget::rightbtn_clicked_slot()
-//{
-//    if(btnPos<letterlistscrollarea->widget()->layout()->count()-1)
-//    {
-//        QLayoutItem* beforeitem=letterlistscrollarea->widget()->layout()->itemAt(btnPos++);
-//        QWidget* beforewid=beforeitem->widget();
-//        QToolButton* beforebtn=qobject_cast<QToolButton*>(beforewid);
-//        beforebtn->setChecked(false);
-//        QLayoutItem* item=letterlistscrollarea->widget()->layout()->itemAt(btnPos);
-//        QWidget* wid=item->widget();
-//        QToolButton* btn=qobject_cast<QToolButton*>(wid);
-//        btn->click();
-////        qDebug()<<"---"<<btn->pos().x();
-////        qDebug()<<"---111---"<<letterlistscrollarea->widget()->pos().x();
-
-//        if((btn->pos().x()+letterlistscrollarea->widget()->pos().x()) >= letterlistscrollarea->width())
-//        {   if(btnPos<letterlistscrollarea->widget()->layout()->count()-1)
-//            {
-//                int val=letterlistscrollarea->horizontalScrollBar()->value();
-//                letterlistscrollarea->horizontalScrollBar()->setValue(val+40);
-//            }
-//            else{
-////                qDebug()<<scrollarea->horizontalScrollBar()->maximum();
-//                letterlistscrollarea->horizontalScrollBar()->setValue(letterlistscrollarea->horizontalScrollBar()->maximum());
-//            }
-
-//        }
-
-////        qDebug()<<scrollarea->horizontalScrollBar()->value();
-
-//    }
-//}
-
-/**
- * 字母列表数据项被选定槽函数
- */
-//void FullLetterWidget::letterbtn_clicked_slot()
-//{
-//    QLayoutItem* item=letterlistscrollarea->widget()->layout()->itemAt(btnPos);
-//    QWidget* wid=item->widget();
-//    QToolButton* beforebtn=qobject_cast<QToolButton*>(wid);
-//    beforebtn->setChecked(false);
-//    QToolButton* btn=dynamic_cast<QToolButton*>(QObject::sender());
-//    btnPos=letterlistscrollarea->widget()->layout()->indexOf(btn);
-//    btn->setChecked(true);
-//    QString letterstr=btn->text().at(0);
-//    //此处需实现将被选定的字母包含的应用列表移动到applistWid界面最顶端
-//    int num=letterbtnlist.indexOf(letterstr);
-//    if(num!=-1)
-//    {
-//        int pos=letterbtnrowlist.at(num).toInt();
-//        scrollarea->verticalScrollBar()->setSliderPosition(pos);
-//    }
-////    emit send_fullletterwid_state(0,letterstr);
-
-//}
